<?php

namespace App\Repository\System;

use App\Entity\Case\CaseLocation;
use App\Entity\System\Location;
use App\Entity\Case\MemberCase;;
use App\Entity\System\User;
use App\Entity\System\UserCase;
use Doctrine\Bundle\DoctrineBundle\Repository\ServiceEntityRepository;
use Doctrine\Persistence\ManagerRegistry;

/**
 * @extends ServiceEntityRepository<Locations>
 */
class LocationRepository extends ServiceEntityRepository
{
    public function __construct(ManagerRegistry $registry)
    {
        parent::__construct($registry, Location::class);
    }

    public function getUserLocations(User $user): array
    {
        $query = $this->createQueryBuilder('location')
            ->leftJoin(CaseLocation::class, 'cl', 'WITH', 'cl.location = location.id')
            ->leftJoin(UserCase::class, 'uc', 'WITH', 'uc.memberCase = cl.memberCase')
            ->andWhere('uc.user = :user')
            ->setParameter('user', $user->getId()->toBinary())
            ->orderBy('location.name', 'ASC')
            ->getQuery()
            ->getResult()
        ;

        return $query;
    }

    public function getLocationsByCase(MemberCase $case): array
    {
        return $this->createQueryBuilder('location')
            ->leftJoin(CaseLocation::class, 'cl', 'WITH', 'cl.location = location.id')
            ->andWhere('cl.memberCase = :case')
            ->setParameter('case', $case->getId()->toBinary())
            ->orderBy('location.name', 'ASC')
            ->getQuery()
            ->getResult()
        ;
    }

    //    /**
    //     * @return Locations[] Returns an array of Locations objects
    //     */
    //    public function findByExampleField($value): array
    //    {
    //        return $this->createQueryBuilder('l')
    //            ->andWhere('l.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->orderBy('l.id', 'ASC')
    //            ->setMaxResults(10)
    //            ->getQuery()
    //            ->getResult()
    //        ;
    //    }

    //    public function findOneBySomeField($value): ?Locations
    //    {
    //        return $this->createQueryBuilder('l')
    //            ->andWhere('l.exampleField = :val')
    //            ->setParameter('val', $value)
    //            ->getQuery()
    //            ->getOneOrNullResult()
    //        ;
    //    }
}
